<?php

class CourseController extends APIController
{
    public function index()
    {
        $courses = Course::with('teacher', 'students', 'attendances')->get();
        return $this->status(200)->response(array(
            'courses'   =>  $courses->toArray(),
            'total'     =>  count($courses),
        ));
    }

	public function show($courseId)
	{
		$course = Course::with('teacher', 'students', 'attendances')->whereId($courseId)->first();
		if(!$course) {
			return $this->status(404)->response(array('error' => 'Curso no encontrado'));
		}
		return $this->status(200)->response($course->toArray());
	}

	public function store()
	{
		$validation = Validator::make(Input::all(), Course::$validationRules);
		if($validation->fails()) {
			return $this->status(422)->response(array(
				'errors'	=>	$validation->errors()->toArray()
				));
		}
		$course = new Course(Input::all());
		$course->save();
		return $this->status(200)->response($course->toArray());
	}

	public function addStudent($courseId)
	{
		$rules = array(
			'student_id'	=>	'required|exists:students,id',
			);
		$validation = Validator::make(Input::all(), $rules);
		if($validation->fails()) {
			return $this->status(422)->response(array(
				'errors'	=>	$validation->errors()->toArray()
				));
		}
		$course = Course::whereId($courseId)->first();
		if(!$course) {
			return $this->status(404)->response(array('error' => 'Curso no encontrado'));
		}
		try {
			$course->students()->attach(Input::get('student_id'));
		}
		catch(Illuminate\Database\QueryException $e) {
			return $this->status(409)->response(array('error' => 'El estudiante ya esta inscrito en este curso'));
		}
        $course = Course::with('teacher', 'students')->find($courseId);
		return $this->status(200)->response($course->toArray());
	}
}