<?php

class StudentController extends APIController
{
	public function show($studentId)
	{
		$student = Student::with('courses', 'attendances')->whereId($studentId)->first();
		if(!$student) {
			return $this->status(404)->response(array('error' => 'Estudiante no encontrado'));
		}
		return $this->status(200)->response($student->toArray());
	}

    public function index()
    {
        $students = Student::all();
        return $this->status(200)->response(array(
            'students'  =>  $students->toArray(),
            'total'     =>  count($students),
        ));
    }

	public function store()
	{
		$validation = Validator::make(Input::all(), Student::$validationRules);
		if($validation->fails()) {
			return $this->status(422)->response(array(
				'errors'	=>	$validation->errors()->toArray()
				));
		}
		$student = new Student(Input::all());
		$student->save();
		return $this->status(200)->response($student->toArray());
	}

	public function addCourse($studentId)
	{
		$rules = array(
			'course_id'	=>	'required|exists:courses,id',
			);
		$validation = Validator::make(Input::all(), $rules);
		if($validation->fails()) {
			return $this->status(422)->response(array(
				'errors'	=>	$validation->errors()->toArray()
				));
		}
		$student = Student::with('courses')->whereId($studentId)->first();
		if(!$student) {
			return $this->status(404)->response(array('error' => 'Estudiante no encontrado'));
		}
		try {
			$student->courses()->attach(Input::get('course_id'));
		}
		catch(Illuminate\Database\QueryException $e) {
			return $this->status(409)->response(array('error' => 'El estudiante ya esta inscrito en ese curso'));
		}
		return $this->status(200)->response($student->toArray());
	}
}